        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 20 <br>1,8,9,12,14,20,21,22,25,28,29,30,34,38,39,42,44,45,48,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 15 <strong>control</strong><br>0,3,4,5,10,13,23,27,32,33,35,36,40,47,49';}
       if(rr==3 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>11,17,18,24,26,31,41';}
       if(rr==3 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>37</strong> miembros: 6 <br>6,7,15,19,37,43';}
       if(rr==3 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>2</strong> miembros: 3 <br>2,16,46';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 20 <br>1,8,9,12,14,20,21,22,25,28,29,30,34,38,39,42,44,45,48,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 15 <strong>control</strong><br>0,3,4,5,10,13,23,27,32,33,35,36,40,47,49';}
       if(rr==17 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>11,17,18,24,26,31,41';}
       if(rr==17 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>37</strong> miembros: 6 <br>6,7,15,19,37,43';}
       if(rr==17 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>2</strong> miembros: 3 <br>2,16,46';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 20 <br>1,8,9,12,14,20,21,22,25,28,29,30,34,38,39,42,44,45,48,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 15 <strong>control</strong><br>0,3,4,5,10,13,23,27,32,33,35,36,40,47,49';}
       if(rr==19 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>11,17,18,24,26,31,41';}
       if(rr==19 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>37</strong> miembros: 6 <br>6,7,15,19,37,43';}
       if(rr==19 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>2</strong> miembros: 3 <br>2,16,46';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 20 <br>1,8,9,12,14,20,21,22,25,28,29,30,34,38,39,42,44,45,48,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 15 <strong>control</strong><br>0,3,4,5,10,13,23,27,32,33,35,36,40,47,49';}
       if(rr==20 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>11,17,18,24,26,31,41';}
       if(rr==20 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>37</strong> miembros: 6 <br>6,7,15,19,37,43';}
       if(rr==20 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>2</strong> miembros: 3 <br>2,16,46';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 20 <br>1,8,9,12,14,20,21,22,25,28,29,30,34,38,39,42,44,45,48,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 15 <strong>control</strong><br>0,3,4,5,10,13,23,27,32,33,35,36,40,47,49';}
       if(rr==21 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>11,17,18,24,26,31,41';}
       if(rr==21 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>37</strong> miembros: 6 <br>6,7,15,19,37,43';}
       if(rr==21 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>2</strong> miembros: 3 <br>2,16,46';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>1</strong> representante: <strong>44</strong> miembros: 20 <br>1,8,9,12,14,20,21,22,25,28,29,30,34,38,39,42,44,45,48,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>2</strong> representante: <strong>49</strong> miembros: 15 <strong>control</strong><br>0,3,4,5,10,13,23,27,32,33,35,36,40,47,49';}
       if(rr==22 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>3</strong> representante: <strong>31</strong> miembros: 7 <br>11,17,18,24,26,31,41';}
       if(rr==22 && cc==4){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>4</strong> representante: <strong>37</strong> miembros: 6 <br>6,7,15,19,37,43';}
       if(rr==22 && cc==5){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260623 a 12</strong> UTC HH+192 (rango:180-204)<br>grupo: <strong>5</strong> representante: <strong>2</strong> miembros: 3 <br>2,16,46';}
}
